@@ -18,7 +18,7 @@
 #'
 #'
 #' @return A PDF file containing the box plots for the continuous variables.
-#'
+#' @author Shubh Saraswat
 #' @examples
 #' # Loading data
 #' data.df <- ExampleData1
@@ -43,7 +43,9 @@ cyt_bp <- function(data, pdf_title, bin_size = 25, y_lim = NULL, scale = NULL) {
   }
 
   n_col <- ncol(data)
-  if (n_col == 0) stop("No columns to plot in 'data'.")
+  if (n_col == 0) {
+    stop("No columns to plot in 'data'.")
+  }
 
   n_chunks <- ceiling(n_col / bin_size)
   plot_list <- vector("list", n_chunks)
@@ -53,23 +55,30 @@ cyt_bp <- function(data, pdf_title, bin_size = 25, y_lim = NULL, scale = NULL) {
     end_idx <- min(i * bin_size, n_col)
     chunk_cols <- names(data)[start_idx:end_idx]
 
-    melted <- reshape2::melt(data[, chunk_cols, drop = FALSE],
-                             measure.vars = chunk_cols,
-                             variable.name = "Variable",
-                             value.name = "Value")
+    melted <- reshape2::melt(
+      data[, chunk_cols, drop = FALSE],
+      measure.vars = chunk_cols,
+      variable.name = "Variable",
+      value.name = "Value"
+    )
 
     p <- ggplot2::ggplot(melted, ggplot2::aes(x = Variable, y = Value)) +
       ggplot2::geom_boxplot() +
-      ggplot2::labs(title = "Boxplots for Variables:",
-                    x = "Variable", y = "Value") +
+      ggplot2::labs(
+        title = "Boxplots for Variables:",
+        x = "Variable",
+        y = "Value"
+      ) +
       ggplot2::theme_minimal() +
-      ggplot2::theme(axis.text.x = ggplot2::element_text(angle = 90, vjust = 0.5, hjust = 1),
-    panel.background = element_rect(fill = "white", colour = "white"),
-    plot.background = element_rect(fill = "white", colour = "white"),
-    legend.background = element_rect(fill = "white", colour = "white"),
-    axis.title = element_text(color = "black", size = 12, face = "bold"),
-    legend.title = element_text(color = "black", size = 10, face = "bold"),
-    legend.text = element_text(color = "black"))
+      ggplot2::theme(
+        axis.text.x = ggplot2::element_text(angle = 90, vjust = 0.5, hjust = 1),
+        panel.background = element_rect(fill = "white", colour = "white"),
+        plot.background = element_rect(fill = "white", colour = "white"),
+        legend.background = element_rect(fill = "white", colour = "white"),
+        axis.title = element_text(color = "black", size = 12, face = "bold"),
+        legend.title = element_text(color = "black", size = 10, face = "bold"),
+        legend.text = element_text(color = "black")
+      )
 
     if (!is.null(y_lim)) {
       p <- p + ggplot2::coord_cartesian(ylim = y_lim)
