@@ -20,6 +20,8 @@
 #'
 #' @return A PDF file containing the boxplots.
 #'
+#' @author Shubh Saraswat
+#'
 #' @examples
 #' # Loading data
 #' data_df <- ExampleData1[, -c(3, 5:28)]
@@ -29,8 +31,7 @@
 #' @export
 #' @import ggplot2
 
-cyt_bp2 <- function(data, pdf_title,
-                    scale = NULL, y_lim = NULL) {
+cyt_bp2 <- function(data, pdf_title, scale = NULL, y_lim = NULL) {
   # Convert any character variables to factors
   cat_vars <- sapply(data, is.character)
   if (any(cat_vars)) {
@@ -42,8 +43,12 @@ cyt_bp2 <- function(data, pdf_title,
   fac_cols <- sapply(data, is.factor)
 
   # Ensure there is at least one numeric and one factor column
-  if (!any(num_cols)) stop("Data must contain at least one numeric column")
-  if (!any(fac_cols)) stop("Data must contain at least one factor column")
+  if (!any(num_cols)) {
+    stop("Data must contain at least one numeric column")
+  }
+  if (!any(fac_cols)) {
+    stop("Data must contain at least one factor column")
+  }
 
   # Apply log2 transformation if scale is "log2"
   if (!is.null(scale) && scale == "log2") {
@@ -61,23 +66,32 @@ cyt_bp2 <- function(data, pdf_title,
     # Loop through each factor column
     for (fac_col in names(data)[fac_cols]) {
       # Create the boxplot
-      p <- ggplot2::ggplot(data, aes_string(x = fac_col,
-                                   y = num_col, fill = fac_col)) +
+      p <- ggplot2::ggplot(
+        data,
+        aes_string(x = fac_col, y = num_col, fill = fac_col)
+      ) +
         ggplot2::geom_boxplot(alpha = 0.5) +
         ggplot2::geom_jitter(width = 0.2, alpha = 0.5) +
         ggplot2::labs(
           title = paste0(num_col, " by ", fac_col),
-          x = fac_col, y = paste0("Values of ", num_col)
+          x = fac_col,
+          y = paste0("Values of ", num_col)
         ) +
         ggplot2::theme_minimal() +
-        ggplot2::theme(legend.position = "bottom",
-              plot.title = element_text(hjust = 0.5),
-              panel.background = element_rect(fill = "white", colour = "white"),
-              plot.background = element_rect(fill = "white", colour = "white"),
-              legend.background = element_rect(fill = "white", colour = "white"),
-              axis.title = element_text(color = "black", size = 12, face = "bold"),
-              legend.title = element_text(color = "black", size = 10, face = "bold"),
-              legend.text = element_text(color = "black")) +
+        ggplot2::theme(
+          legend.position = "bottom",
+          plot.title = element_text(hjust = 0.5),
+          panel.background = element_rect(fill = "white", colour = "white"),
+          plot.background = element_rect(fill = "white", colour = "white"),
+          legend.background = element_rect(fill = "white", colour = "white"),
+          axis.title = element_text(color = "black", size = 12, face = "bold"),
+          legend.title = element_text(
+            color = "black",
+            size = 10,
+            face = "bold"
+          ),
+          legend.text = element_text(color = "black")
+        ) +
         ggplot2::guides(fill = guide_legend(title = NULL))
 
       if (!is.null(y_lim)) {
